@@ -5,11 +5,10 @@ use crate::{
     node::attribute::group_attributes_per_name, Attribute, Element, Node,
     Patch, TreePath,
 };
-use keyed_elements::diff_keyed_elements;
 use std::fmt::Debug;
 use std::{cmp, mem};
 
-mod keyed_elements;
+mod keyed;
 
 /// Return the patches needed for `old_node` to have the same DOM as `new_node`
 ///
@@ -258,10 +257,10 @@ where
     match (old_node, new_node) {
         (Node::Leaf(old_leaf), Node::Leaf(new_leaf)) => {
             if old_leaf != new_leaf {
-                let ct = Patch::replace_leaf(
+                let ct = Patch::replace_node(
+                    old_node.tag(),
                     TreePath::new(path.to_vec()),
-                    old_leaf,
-                    new_leaf,
+                    new_node,
                 );
                 patches.push(ct);
             }
@@ -272,7 +271,7 @@ where
                 || is_any_children_keyed(new_element, key);
 
             if test {
-                let keyed_patches = keyed_elements::diff_keyed_elements(
+                let keyed_patches = keyed::diff_keyed_elements(
                     old_element,
                     new_element,
                     key,
