@@ -18,7 +18,7 @@ use std::fmt::Debug;
 pub struct Element<NS, TAG, LEAF, ATT, VAL>
 where
     NS: PartialEq + Clone + Debug,
-    TAG: PartialEq + Clone + Debug,
+    TAG: PartialEq + Debug,
     LEAF: PartialEq + Clone + Debug,
     ATT: PartialEq + Clone + Debug,
     VAL: PartialEq + Clone + Debug,
@@ -39,7 +39,7 @@ where
 impl<NS, TAG, LEAF, ATT, VAL> Element<NS, TAG, LEAF, ATT, VAL>
 where
     NS: PartialEq + Clone + Debug,
-    TAG: PartialEq + Clone + Debug,
+    TAG: PartialEq + Debug,
     LEAF: PartialEq + Clone + Debug,
     ATT: PartialEq + Clone + Debug,
     VAL: PartialEq + Clone + Debug,
@@ -74,9 +74,7 @@ where
         &mut self,
         children: impl IntoIterator<Item = Node<NS, TAG, LEAF, ATT, VAL>>,
     ) {
-        let mut new_children: Vec<Node<NS, TAG, LEAF, ATT, VAL>> =
-            children.into_iter().collect();
-        self.children.append(&mut new_children);
+        self.children.extend(children.into_iter());
     }
 
     /// returns a refernce to the children of this node
