@@ -1,7 +1,8 @@
 #![deny(warnings)]
 use mt_dom::*;
 
-pub type MyNode = Node<&'static str, &'static str, &'static str, &'static str>;
+pub type MyNode =
+    Node<&'static str, &'static str, &'static str, &'static str, &'static str>;
 
 #[test]
 fn node_count1() {
@@ -13,10 +14,10 @@ fn node_count1() {
 
 #[test]
 fn node_count3() {
-    let old: MyNode = element("div", vec![], vec![text("0"), text("1")]);
+    let old: MyNode = element("div", vec![], vec![leaf("0"), leaf("1")]);
 
     // 4 instead of 3, because we automatically inserted a separator in between 2 sibling texts
-    assert_eq!(4, old.node_count());
+    assert_eq!(3, old.node_count());
 }
 
 #[test]
@@ -52,7 +53,7 @@ fn node_count6() {
                 vec![],
                 vec![
                     element("i", vec![], vec![]),
-                    element("i", vec![], vec![text("hi")]),
+                    element("i", vec![], vec![leaf("hi")]),
                 ],
             ),
             element("b", vec![], vec![]),
